from ._uirevision import UirevisionValidator
from ._orientation import OrientationValidator
from ._color import ColorValidator
from ._bgcolor import BgcolorValidator
from ._activecolor import ActivecolorValidator



import _plotly_utils.basevalidators


class ColorscaleValidator(_plotly_utils.basevalidators.CompoundValidator):

    def __init__(
        self, plotly_name='colorscale', parent_name='layout', **kwargs
    ):
        super(ColorscaleValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            data_class_str=kwargs.pop('data_class_str', 'Colorscale'),
            data_docs=kwargs.pop(
                'data_docs', """
            diverging
                Sets the default diverging colorscale. Note
                that `autocolorscale` must be true for this
                attribute to work.
            sequential
                Sets the default sequential colorscale for
                positive values. Note that `autocolorscale`
                must be true for this attribute to work.
            sequentialminus
                Sets the default sequential colorscale for
                negative values. Note that `autocolorscale`
                must be true for this attribute to work.
"""
            ),
            **kwargs
        )



import _plotly_utils.basevalidators


class CapsValidator(_plotly_utils.basevalidators.CompoundValidator):

    def __init__(self, plotly_name='caps', parent_name='isosurface', **kwargs):
        super(CapsValidator, self).__init__(
            plotly_name=plotly_name,
            parent_name=parent_name,
            data_class_str=kwargs.pop('data_class_str', 'Caps'),
            data_docs=kwargs.pop(
                'data_docs', """
            x
                plotly.graph_objs.isosurface.caps.X instance or
                dict with compatible properties
            y
                plotly.graph_objs.isosurface.caps.Y instance or
                dict with compatible properties
            z
                plotly.graph_objs.isosurface.caps.Z instance or
                dict with compatible properties
"""
            ),
            **kwargs
        )
